/*
 * $Id: scpm.hh,v 1.5 2006/11/02 16:15:01 gleissner Exp $
 *
 *
 * Project		 :	SCPM (System Configuration Profile Management)
 * Module			 :	SCPM main engine
 * File				 :	scpm.hh
 * Description :	defines the SCPM interface
 * Author			 :	Joachim Gleissner <jg@suse.de>
 *
 * Copyright 2001 SuSE GmbH
 *					 2002-2004 SuSE Linux AG
 *
 * Released under the terms of the GNU General Public License
 * (see file COPYRIGHT in project root directory).
 *
 */
#ifndef SCPM_H
#define SCPM_H

#include <string>
#include <vector>
#include <scpm_types.h>
#include <scdb.h>

class SCPM_helpers;
class Log;

class SCPM
{
public:

	SCPM( int options=0, std::ostream &info_out=std::cout, std::ostream &hash_out=std::cout, std::string root="" );
	~SCPM();

	bool Enable( bool force=false );
	bool Disable( );

	bool Active( std::string &profile );
	bool List( std::vector<std::string> &profiles );

	bool Add( std::string profile, bool auto_switch=true );
	bool Copy( std::string source_profile, std::string profile );
	bool Create( std::string profile, std::string source_profile );
	bool Delete( std::string profile );
	bool Rename( std::string profile, std::string newprofile );
	bool Reload( );
	bool PrepareSwitch( std::string profile, switch_info_t &switch_info );
	bool Switch( switch_info_t &switch_info );
	bool Save( switch_info_t &switch_info );
	bool Modify( std::string profile, std::string action );
	bool Set( std::string command, std::string argument, std::string profile="" );
	bool Get( std::string command, std::string &result, std::string profile="" );
	bool Status( scpm_status_t &status );

	bool ShowChanges( std::ostream &output, std::string resource_type,
										std::string resource_name, bool backup=false, std::string version="" );

	bool SetResourceSet( std::string set );
	bool GetResourceSet( std::string &set );
	bool ListResourceSets( std::vector<std::string> &predefined, std::vector<std::string> &individual );
	bool CopyResourceSet( std::string set, std::string newset );
	bool DeleteResourceSet( std::string set );

	bool ListResourceGroups( std::vector<resource_group_t> &groups );
	bool GetResourceGroup( const std::string &name, std::vector<resource_entry_t> &group,
												 bool nouser=false );
	bool GetResourceGroup( const std::string &name, std::vector<resource_entry_t> &group,
												 std::string &description, bool nouser=false );
	bool SetResourceGroup( const std::string &name, const std::vector<resource_entry_t> &group,
												 const std::string &description );
	bool DeleteResourceGroup( const std::string &group );
	bool RenameResourceGroup( const std::string &group, const std::string &newgroup );
	bool SetActiveResourceGroups( const std::vector<std::string> &groups );
	bool GetActiveResourceGroups( std::vector<std::string> &groups );
	bool ActivateResourceGroup( const std::string &group, bool auto_add=false );
	bool DeactivateResourceGroup( const std::string &group, bool auto_remove=false );
	bool ResetResourceGroup( const std::string &group );
	bool ResetAllGroups( );

	bool RebuildDB( rebuild_mode_t mode=REBUILD_MODE_QUICK );

	bool SetConfigOption( const std::string &option, const std::string &value );
	bool GetConfigOption( const std::string &option, std::string &value );

		// update and backup functions
	bool Update( const std::string &scriptname, std::vector<std::pair<std::string, std::string> > resources );
	bool UpdateResources( );
	bool RestoreBackup(	const std::vector<std::pair<std::string, std::string> > &resources,
                      const std::vector<std::string> &versions, const std::string &profile );
	bool RemoveBackup(	const std::vector<std::pair<std::string, std::string> > &resources,
	                    const std::vector<std::string> &versions, const std::string &profile );
	bool ListBackups(	const std::string &profile, std::vector<backup_info_t> *reslist );
	bool AddBackup(	const std::vector<std::pair<std::string, std::string> > &resources,
	                const std::string &profile);
	bool Recover(	bool rollback=false );

	bool Commit( );

private:

	struct prepare_failed{};

	std::vector<resource_group_t> &GetGroupsByResource( const std::string &resname,
	                                                    const std::string &restype );
	void Prepare( bool write_access=false );

	SCPM_helpers *sh;
	Log *log;
	bool db_open;
	bool switch_prepared;
	bool init_failed;

};

#endif
