/*
 * $Id: scpm_types.h,v 1.3 2006/09/21 12:36:16 hschaa Exp $
 *
 * Type definitions for the SCPM interface.
 *
 * Copyright 2001 SuSE GbmH
 *           2002-2004 SuSE Linux AG
 *
 * Author: Joachim Gleissner <jg@suse.de>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef SCPM_TYPES_H
#define SCPM_TYPES_H

#include <string>
#include <vector>
#include <unistd.h>

enum save_mode_t {
  normal,
  save_all,
  patch_all
} ;

struct resource_group_t {
  std::string name;
  std::string description;
  bool user_defined;
  bool user_modified;
  bool active;
} ;

struct resource_entry_t {
  std::string name;
  std::string type;
  bool active;
  bool user_defined;
} ;

struct resource_info_t {
  std::string resource_name;
  std::string resource_type;
  bool   is_new;
  bool   is_deleted;
  bool   save;
  save_mode_t save_mode;
  std::vector<resource_group_t> groups;
} ;

struct switch_info_t {
  bool profile_modified;
  std::string profile_name;
  std::vector<resource_info_t> modified_resources;
} ;

struct scpm_status_t {
  bool initialized;
  bool enabled;
  bool db_loaded;
  bool db_uptodate;
  bool locked;
  bool needs_reinit;
  bool needs_recover;
  std::string active_profile;
  std::string scpm_version;
  std::string db_version;
  std::string db_format;
  std::string db_format_version;
} ;

struct backup_info_t {
  std::string name;
  std::string type;
  std::string profile;
	std::vector< std::pair<time_t, std::string> > versions;
} ;

enum rebuild_mode_t {
  REBUILD_MODE_QUICK,
  REBUILD_MODE_RESOURCES_ONLY,
  REBUILD_MODE_DATA_ONLY,
  REBUILD_MODE_FULL
};

extern char *scpm_error;
extern int scpm_journal_abort_steps;

const int scpm_flag_force           = 1;
const int scpm_flag_skip            = 2;
const int scpm_flag_quiet           = 4;
const int scpm_flag_verbose         = 8;
const int scpm_flag_hash            = 16;
const int scpm_flag_debug           = 32;
const int scpm_flag_boot            = 64;
const int scpm_flag_exit_on_warning = 128;
const int scpm_flag_skip_load       = 256;
const int scpm_flag_force_db        = 512;
const int scpm_flag_read_only       = 1024;
const int scpm_flag_wait_commit     = 2048;

#endif
